@@ -1,10 +1,6 @@
 from django.conf import settings
 
 
-__all__ = ['user_model', 'get_username', 'SiteProfileNotAvailable', 'etree',
-           'register_namespace', 'gevent']
-
-
 # Django >= 1.5 uses AUTH_USER_MODEL to specify the currently active
 # User model. Previous versions of Django do not have this setting
 # and use the built-in User model.
@@ -13,6 +9,18 @@ __all__ = ['user_model', 'get_username', 'SiteProfileNotAvailable', 'etree',
 user_model = getattr(settings, 'AUTH_USER_MODEL', 'auth.User')
 
 
+# In Django >= 1.5 get_user_model() returns the currently active
+# User model. Previous versions of Django have no concept of custom
+# User models and reference User directly.
+#
+# This is not needed when support for Django 1.4 is dropped.
+try:
+    from django.contrib.auth import get_user_model
+except ImportError: # pragma: no cover
+    from django.contrib.auth.models import User
+    get_user_model = lambda: User
+
+
 # As custom user models can change the username field, Django >= 1.5
 # uses get_username() to access the username field. Previous versions
 # of Django do not have this method and access username directly.
@@ -70,5 +78,13 @@ except AttributeError:  # pragma: no cover
 # requests. If it is not present, synchronous requests will be sent.
 try:
     import gevent
-except ImportError:
+except ImportError:  # pragma: no cover
     gevent = None
+
+
+# Support both Python 2 and Python 3 locations for urllib imports.
+try:
+    from urllib.parse import parse_qsl, urlencode, urlparse, urlunparse
+except ImportError:  # pragma: no cover
+    from urllib import urlencode
+    from urlparse import parse_qsl, urlparse, urlunparse
