@@ -149,7 +149,7 @@ class CustomAttributesMixin(object):
     """
     View mixin for including user attributes in a validation response.
     """
-    def get_custom_attributes(self, ticket):
+    def get_custom_attributes(self, user):
         """
         Build a dictionary of user attributes from the ``User``
         object, the user profile object or custom callbacks using one
@@ -172,9 +172,6 @@ class CustomAttributesMixin(object):
 
         All attributes are returned as a single dictionary.
         """
-        if not ticket:
-            return None
-        user = ticket.user
         attributes = {}
 
         user_attr_list = getattr(settings, 'MAMA_CAS_USER_ATTRIBUTES', {})
@@ -183,7 +180,7 @@ class CustomAttributesMixin(object):
                 "The MAMA_CAS_USER_ATTRIBUTES setting is deprecated and "
                 "will be removed in MamaCAS 1.0. Use the "
                 "MAMA_CAS_ATTRIBUTE_CALLBACKS setting instead.",
-                PendingDeprecationWarning)
+                DeprecationWarning)
         for name, attr in user_attr_list.items():
             try:
                 attributes[name] = getattr(user, attr)
@@ -202,7 +199,7 @@ class CustomAttributesMixin(object):
                     "The MAMA_CAS_PROFILE_ATTRIBUTES setting is deprecated "
                     "and will be removed in MamaCAS 1.0. Use the "
                     "MAMA_CAS_ATTRIBUTE_CALLBACKS setting instead.",
-                    PendingDeprecationWarning)
+                    DeprecationWarning)
             for name, attr in profile_attr_list.items():
                 try:
                     attributes[name] = getattr(profile, attr)
