@@ -1,5 +1,6 @@
 from django.contrib.auth.backends import ModelBackend
-from django.contrib.auth.models import User
+
+from mama_cas.compat import get_user_model
 
 
 class ExceptionBackend(ModelBackend):
@@ -11,9 +12,10 @@ class ExceptionBackend(ModelBackend):
 class CaseInsensitiveBackend(ModelBackend):
     """A case-insenstitive authentication backend."""
     def authenticate(self, username=None, password=None):
+        user_model = get_user_model()
         try:
-            user = User.objects.get(username__iexact=username)
+            user = user_model.objects.get(username__iexact=username)
             if user.check_password(password):
                 return user
-        except User.DoesNotExist:
+        except user_model.DoesNotExist:
             return None
