@@ -1,22 +1,19 @@
 from __future__ import unicode_literals
 
-from django.core.exceptions import ImproperlyConfigured
 from django.test import TestCase
-from django.test.utils import override_settings
 
 from .factories import ProxyGrantingTicketFactory
 from .factories import ProxyTicketFactory
 from .factories import ServiceTicketFactory
+from .factories import ConsumedServiceTicketFactory
 from .utils import parse
 from mama_cas.exceptions import InvalidTicket
 from mama_cas.response import ValidationResponse
 from mama_cas.response import ProxyResponse
+from mama_cas.response import SamlValidationResponse
 
 
 class ValidationResponseTests(TestCase):
-    """
-    Test the ``ValidationResponse`` XML output.
-    """
     def setUp(self):
         self.st = ServiceTicketFactory()
         self.pgt = ProxyGrantingTicketFactory()
@@ -81,11 +78,10 @@ class ValidationResponseTests(TestCase):
         self.assertEqual(proxies[0].text, proxy_list[0])
         self.assertEqual(proxies[1].text, proxy_list[1])
 
-    @override_settings(MAMA_CAS_ATTRIBUTE_FORMAT='jasig')
-    def test_validation_response_jasig_attributes(self):
+    def test_validation_response_attributes(self):
         """
         When given custom user attributes, a ``ValidationResponse``
-        should include the attributes in the configured format.
+        should include the attributes in the response.
         """
         attrs = {'givenName': 'Ellen', 'sn': 'Cohen', 'email': 'ellen@example.com'}
         resp = ValidationResponse(context={'ticket': self.st, 'error': None,
@@ -103,71 +99,8 @@ class ValidationResponseTests(TestCase):
             del attrs[child.tag]
         self.assertEqual(len(attrs), 0)
 
-    @override_settings(MAMA_CAS_ATTRIBUTE_FORMAT='rubycas')
-    def test_validation_response_rubycas_attributes(self):
-        """
-        When given custom user attributes, a ``ValidationResponse``
-        should include the attributes in the configured format.
-        """
-        attrs = {'givenName': 'Ellen', 'sn': 'Cohen', 'email': 'ellen@example.com'}
-        resp = ValidationResponse(context={'ticket': self.st, 'error': None,
-                                           'attributes': attrs},
-                                  content_type='text/xml')
-        success = parse(resp.content).find('./authenticationSuccess')
-        self.assertIsNotNone(success)
-        # The authenticationSuccess tag should include a child for
-        # each attribute, plus the user element
-        self.assertEqual(len(success), len(attrs) + 1)
-        for child in success:
-            if child.tag == 'user':
-                continue
-            self.assertTrue(child.tag in attrs)
-            self.assertEqual(child.text, attrs[child.tag])
-            # Ordering is not guaranteed, so remove attributes from
-            # the dict as they are validated. When done, check if the
-            # dict is empty to see if all attributes were matched.
-            del attrs[child.tag]
-        self.assertEqual(len(attrs), 0)
-
-    @override_settings(MAMA_CAS_ATTRIBUTE_FORMAT='namevalue')
-    def test_validation_response_namevalue_attributes(self):
-        """
-        When given custom user attributes, a ``ValidationResponse``
-        should include the attributes in the configured format.
-        """
-        attrs = {'givenName': 'Ellen', 'sn': 'Cohen', 'email': 'ellen@example.com'}
-        resp = ValidationResponse(context={'ticket': self.st, 'error': None,
-                                           'attributes': attrs},
-                                  content_type='text/xml')
-        success = parse(resp.content).find('./authenticationSuccess')
-        self.assertIsNotNone(success)
-        self.assertEqual(len(success.findall('attribute')), len(attrs))
-        for elem in success.findall('attribute'):
-            self.assertTrue(elem.get('name') in attrs)
-            self.assertEqual(elem.get('value'), attrs[elem.get('name')])
-            # Ordering is not guaranteed, so remove attributes from
-            # the dict as they are validated. When done, check if the
-            # dict is empty to see if all attributes were matched.
-            del attrs[elem.get('name')]
-        self.assertEqual(len(attrs), 0)
-
-    @override_settings(MAMA_CAS_ATTRIBUTE_FORMAT='invalid')
-    def test_validation_response_invalid_attribute_format(self):
-        """
-        Configuring an invalid attribute format should raise an
-        ``ImproperlyConfigured`` exception.
-        """
-        attrs = {'givenName': 'Ellen', 'sn': 'Cohen', 'email': 'ellen@example.com'}
-        with self.assertRaises(ImproperlyConfigured):
-            ValidationResponse(context={'ticket': self.st, 'error': None,
-                                        'attributes': attrs},
-                               content_type='text/xml')
-
 
 class ProxyResponseTests(TestCase):
-    """
-    Test the ``ProxyResponse`` XML output.
-    """
     def setUp(self):
         self.st = ServiceTicketFactory()
         self.pgt = ProxyGrantingTicketFactory()
@@ -205,3 +138,58 @@ class ProxyResponseTests(TestCase):
         self.assertIsNotNone(failure)
         self.assertEqual(failure.get('code'), 'INVALID_TICKET')
         self.assertEqual(failure.text, 'Testing Error')
+
+
+class SamlValidationResponseTests(TestCase):
+    def setUp(self):
+        self.st = ConsumedServiceTicketFactory()
+
+    def test_saml_validation_response_ticket(self):
+        """
+        When given a ticket, a ``SamlValidationResponse`` should return
+        an authentication success.
+        """
+        resp = SamlValidationResponse(context={'ticket': self.st, 'error': None},
+                                      content_type='text/xml')
+        code = parse(resp.content).find('./Body/Response/Status/StatusCode')
+        self.assertIsNotNone(code)
+        self.assertEqual(code.get('Value'), 'samlp:Success')
+
+    def test_saml_validation_response_error(self):
+        """
+        When given an error, a ``SamlValidationResponse`` should return
+        an authentication failure with the error text.
+        """
+        error = InvalidTicket('Testing Error')
+        resp = SamlValidationResponse(context={'ticket': None, 'error': error},
+                                      content_type='text/xml')
+        code = parse(resp.content).find('./Body/Response/Status/StatusCode')
+        self.assertIsNotNone(code)
+        self.assertEqual(code.get('Value'), 'samlp:RequestDenied')
+
+        message = parse(resp.content).find('./Body/Response/Status/StatusMessage')
+        self.assertIsNotNone(message)
+        self.assertEqual(message.text, 'Testing Error')
+
+    def test_saml_validation_response_attributes(self):
+        """
+        When given custom user attributes, a ``SamlValidationResponse``
+        authentication success should include the attributes in the
+        response.
+        """
+        attrs = {'givenName': 'Ellen', 'sn': 'Cohen', 'email': 'ellen@example.com'}
+        resp = SamlValidationResponse(context={'ticket': self.st, 'error': None,
+                                               'attributes': attrs},
+                                      content_type='text/xml')
+        attribute_statement = parse(resp.content).find('./Body/Response/Assertion/AttributeStatement')
+        self.assertIsNotNone(attribute_statement)
+        for attr in attribute_statement.findall('Attribute'):
+            attr_name = attr.get('AttributeName')
+            attr_value = attr.find('AttributeValue')
+            self.assertTrue(attr_name in attrs)
+            self.assertEqual(attr_value.text, attrs[attr_name])
+            # Ordering is not guaranteed, so remove attributes from
+            # the dict as they are validated. When done, check if the
+            # dict is empty to see if all attributes were matched.
+            del attrs[attr_name]
+        self.assertEqual(len(attrs), 0)
